BB.LiveView.Plugs.Static (bb_liveview v0.2.3)

Serves static assets bundled with the BB LiveView library.

Assets are served from the library's priv/static directory with appropriate cache headers based on content hashing.

Summary

Functions

Returns the path to an asset file for use in templates.

Functions

asset_path(file)

@spec asset_path(String.t()) :: String.t()

Returns the path to an asset file for use in templates.

The path includes a hash of the file contents for cache busting.